"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_cluster_snapshot_identifier: str,
    target_db_cluster_snapshot_identifier: str,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    copy_tags: bool = None,
    tags: List = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies a snapshot of a cluster. To copy a cluster snapshot from a shared manual cluster snapshot, SourceDBClusterSnapshotIdentifier must be the Amazon Resource Name (ARN) of the shared cluster snapshot. You can only copy a shared DB cluster snapshot, whether encrypted or not, in the same Region. To cancel the copy operation after it is in progress, delete the target cluster snapshot identified by TargetDBClusterSnapshotIdentifier while that cluster snapshot is in the copying status.

    Args:
        source_db_cluster_snapshot_identifier(str): The identifier of the cluster snapshot to copy. This parameter is not case sensitive. Constraints:   Must specify a valid system snapshot in the available state.   If the source snapshot is in the same Region as the copy, specify a valid snapshot identifier.   If the source snapshot is in a different Region than the copy, specify a valid cluster snapshot ARN.   Example: my-cluster-snapshot1 .
        target_db_cluster_snapshot_identifier(str): The identifier of the new cluster snapshot to create from the source cluster snapshot. This parameter is not case sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.    The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.    Example: my-cluster-snapshot2 .
        kms_key_id(str, optional): The KMS key ID for an encrypted cluster snapshot. The KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key alias for the KMS encryption key.  If you copy an encrypted cluster snapshot from your account, you can specify a value for KmsKeyId to encrypt the copy with a new KMS encryption key. If you don't specify a value for KmsKeyId, then the copy of the cluster snapshot is encrypted with the same KMS key as the source cluster snapshot. If you copy an encrypted cluster snapshot that is shared from another account, then you must specify a value for KmsKeyId. To copy an encrypted cluster snapshot to another Region, set KmsKeyId to the KMS key ID that you want to use to encrypt the copy of the cluster snapshot in the destination Region. KMS encryption keys are specific to the Region that they are created in, and you can't use encryption keys from one Region in another Region. If you copy an unencrypted cluster snapshot and specify a value for the KmsKeyId parameter, an error is returned. Defaults to None.
        pre_signed_url(str, optional): The URL that contains a Signature Version 4 signed request for theCopyDBClusterSnapshot API action in the Region that contains the source cluster snapshot to copy. You must use the PreSignedUrl parameter when copying a cluster snapshot from another Region. If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a pre-signed URL that is a valid request for the operation that can be executed in the source Region. The presigned URL must be a valid request for the CopyDBClusterSnapshot API action that can be executed in the source Region that contains the cluster snapshot to be copied. The presigned URL request must contain the following parameter values:    SourceRegion - The ID of the region that contains the snapshot to be copied.    SourceDBClusterSnapshotIdentifier - The identifier for the the encrypted cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Region. For example, if you are copying an encrypted cluster snapshot from the us-east-1 Region, then your SourceDBClusterSnapshotIdentifier looks something like the following: arn:aws:rds:us-east-1:12345678012:sample-cluster:sample-cluster-snapshot.    TargetDBClusterSnapshotIdentifier - The identifier for the new cluster snapshot to be created. This parameter isn't case sensitive.  . Defaults to None.
        copy_tags(bool, optional): Set to true to copy all tags from the source cluster snapshot to the target cluster snapshot, and otherwise false. The default is false. Defaults to None.
        tags(List, optional): The tags to be assigned to the cluster snapshot. Defaults to None.
        source_region(str, optional): The ID of the region that contains the snapshot to be copied. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.snapshot.init.copy(
                ctx,
                source_db_cluster_snapshot_identifier=value,
                target_db_cluster_snapshot_identifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.snapshot.init.copy source_db_cluster_snapshot_identifier=value, target_db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="copy_db_cluster_snapshot",
        op_kwargs={
            "SourceDBClusterSnapshotIdentifier": source_db_cluster_snapshot_identifier,
            "TargetDBClusterSnapshotIdentifier": target_db_cluster_snapshot_identifier,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "CopyTags": copy_tags,
            "Tags": tags,
            "SourceRegion": source_region,
        },
    )


async def create(
    hub,
    ctx,
    db_cluster_snapshot_identifier: str,
    db_cluster_identifier: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a cluster.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the cluster snapshot. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.    Example: my-cluster-snapshot1 .
        db_cluster_identifier(str): The identifier of the cluster to create a snapshot for. This parameter is not case sensitive. Constraints:   Must match the identifier of an existing DBCluster.   Example: my-cluster .
        tags(List, optional): The tags to be assigned to the cluster snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.snapshot.init.create(
                ctx, db_cluster_snapshot_identifier=value, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.snapshot.init.create db_cluster_snapshot_identifier=value, db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_db_cluster_snapshot",
        op_kwargs={
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "DBClusterIdentifier": db_cluster_identifier,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_cluster_snapshot_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a cluster snapshot. If the snapshot is being copied, the copy operation is terminated.  The cluster snapshot must be in the available state to be deleted.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the cluster snapshot to delete. Constraints: Must be the name of an existing cluster snapshot in the available state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.snapshot.init.delete(
                ctx, db_cluster_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.snapshot.init.delete db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_db_cluster_snapshot",
        op_kwargs={"DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier},
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_identifier: str = None,
    db_cluster_snapshot_identifier: str = None,
    snapshot_type: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    include_shared: bool = None,
    include_public: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about cluster snapshots. This API operation supports pagination.

    Args:
        db_cluster_identifier(str, optional): The ID of the cluster to retrieve the list of cluster snapshots for. This parameter can't be used with the DBClusterSnapshotIdentifier parameter. This parameter is not case sensitive.  Constraints:   If provided, must match the identifier of an existing DBCluster.  . Defaults to None.
        db_cluster_snapshot_identifier(str, optional): A specific cluster snapshot identifier to describe. This parameter can't be used with the DBClusterIdentifier parameter. This value is stored as a lowercase string.  Constraints:   If provided, must match the identifier of an existing DBClusterSnapshot.   If this identifier is for an automated snapshot, the SnapshotType parameter must also be specified.  . Defaults to None.
        snapshot_type(str, optional): The type of cluster snapshots to be returned. You can specify one of the following values:    automated - Return all cluster snapshots that Amazon DocumentDB has automatically created for your account.    manual - Return all cluster snapshots that you have manually created for your account.    shared - Return all manual cluster snapshots that have been shared to your account.    public - Return all cluster snapshots that have been marked as public.   If you don't specify a SnapshotType value, then both automated and manual cluster snapshots are returned. You can include shared cluster snapshots with these results by setting the IncludeShared parameter to true. You can include public cluster snapshots with these results by setting theIncludePublic parameter to true. The IncludeShared and IncludePublic parameters don't apply for SnapshotType values of manual or automated. The IncludePublic parameter doesn't apply when SnapshotType is set to shared. The IncludeShared parameter doesn't apply when SnapshotType is set to public. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.
        include_shared(bool, optional): Set to true to include shared manual cluster snapshots from other accounts that this account has been given permission to copy or restore, and otherwise false. The default is false. Defaults to None.
        include_public(bool, optional): Set to true to include manual cluster snapshots that are public and can be copied or restored by any account, and otherwise false. The default is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_db_cluster_snapshots",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "SnapshotType": snapshot_type,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "IncludeShared": include_shared,
            "IncludePublic": include_public,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List all versions for a document.

    Args:
        name(str): The name of the document. You can specify an Amazon Resource Name (ARN).
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.version.list_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.version.list_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_document_versions",
        op_kwargs={"Name": name, "MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_image_name: str,
    destination_image_name: str,
    destination_region: str,
    destination_image_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the image within the same region or to a new region within the same AWS account. Note that any tags you added to the image will not be copied.

    Args:
        source_image_name(str): The name of the image to copy.
        destination_image_name(str): The name that the image will have when it is copied to the destination.
        destination_region(str): The destination region to which the image will be copied. This parameter is required, even if you are copying an image within the same region.
        destination_image_description(str, optional): The description that the image will have when it is copied to the destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.init.copy(
                ctx, source_image_name=value, destination_image_name=value, destination_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.init.copy source_image_name=value, destination_image_name=value, destination_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="copy_image",
        op_kwargs={
            "SourceImageName": source_image_name,
            "DestinationImageName": destination_image_name,
            "DestinationRegion": destination_region,
            "DestinationImageDescription": destination_image_description,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified image. You cannot delete an image when it is in use. After you delete an image, you cannot provision new capacity using the image.

    Args:
        name(str): The name of the image.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_image",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub,
    ctx,
    names: List = None,
    arns: List = None,
    type_: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided. Otherwise, all images in the account are described.

    Args:
        names(List, optional): The names of the public or private images to describe. Defaults to None.
        arns(List, optional): The ARNs of the public, private, and shared images to describe. Defaults to None.
        type_(str, optional): The type of image (public, private, or shared) to describe. . Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        max_results(int, optional): The maximum size of each page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_images",
        op_kwargs={
            "Names": names,
            "Arns": arns,
            "Type": type_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list", "set_": "set"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags associated with an assessment template.

    Args:
        resource_arn(str): The ARN that specifies the assessment template whose tags you want to list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn},
    )


async def set_(hub, ctx, resource_arn: str, tags: List = None) -> None:
    r"""
    **Autogenerated function**

    Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.

    Args:
        resource_arn(str): The ARN of the assessment template that you want to set tags to.
        tags(List, optional): A collection of key and value pairs that you want to set to the assessment template. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.tags_for_resource.set(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.tags_for_resource.set resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="set_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    load_balancer_name: str,
    instance_port: int,
    health_check_path: str = None,
    certificate_name: str = None,
    certificate_domain_name: str = None,
    certificate_alternative_names: List = None,
    tags: List = None,
    ip_address_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Lightsail load balancer. To learn more about deciding whether to load balance your application, see Configure your Lightsail instances for load balancing. You can create up to 5 load balancers per AWS Region in your account. When you create a load balancer, you can specify a unique name and port settings. To change additional load balancer settings, use the UpdateLoadBalancerAttribute operation. The create load balancer operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The name of your load balancer.
        instance_port(int): The instance port where you're creating your load balancer.
        health_check_path(str, optional): The path you provided to perform the load balancer health check. If you didn't specify a health check path, Lightsail uses the root path of your website (e.g., "/"). You may want to specify a custom health check path other than the root of your application if your home page loads slowly or has a lot of media or scripting on it. Defaults to None.
        certificate_name(str, optional): The name of the SSL/TLS certificate. If you specify certificateName, then certificateDomainName is required (and vice-versa). Defaults to None.
        certificate_domain_name(str, optional): The domain name with which your certificate is associated (e.g., example.com). If you specify certificateDomainName, then certificateName is required (and vice-versa). Defaults to None.
        certificate_alternative_names(List, optional): The optional alternative domains and subdomains to use with your SSL/TLS certificate (e.g., www.example.com, example.com, m.example.com, blog.example.com). Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.
        ip_address_type(str, optional): The IP address type for the load balancer. The possible values are ipv4 for IPv4 only, and dualstack for IPv4 and IPv6. The default value is dualstack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.init.create(
                ctx, load_balancer_name=value, instance_port=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.init.create load_balancer_name=value, instance_port=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_load_balancer",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "instancePort": instance_port,
            "healthCheckPath": health_check_path,
            "certificateName": certificate_name,
            "certificateDomainName": certificate_domain_name,
            "certificateAlternativeNames": certificate_alternative_names,
            "tags": tags,
            "ipAddressType": ip_address_type,
        },
    )


async def delete(hub, ctx, load_balancer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Lightsail load balancer and all its associated SSL/TLS certificates. Once the load balancer is deleted, you will need to create a new load balancer, create a new certificate, and verify domain ownership again. The delete load balancer operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The name of the load balancer you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.init.delete(
                ctx, load_balancer_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.init.delete load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_load_balancer",
        op_kwargs={"loadBalancerName": load_balancer_name},
    )


async def get(hub, ctx, load_balancer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified Lightsail load balancer.

    Args:
        load_balancer_name(str): The name of the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.init.get(ctx, load_balancer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.init.get load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_load_balancer",
        op_kwargs={"loadBalancerName": load_balancer_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all load balancers in an account.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetLoadBalancers request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_load_balancers",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    project_name: str,
    service_catalog_provisioning_details: Dict,
    project_description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a machine learning (ML) project that can contain one or more templates that set up an ML pipeline from training to deploying an approved model.

    Args:
        project_name(str): The name of the project.
        project_description(str, optional): A description for the project. Defaults to None.
        service_catalog_provisioning_details(Dict): The product ID and provisioning artifact ID to provision a service catalog. For information, see What is Amazon Web Services Service Catalog.
        tags(List, optional): An array of key-value pairs that you want to use to organize and track your Amazon Web Services resource costs. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.project.create(
                ctx, project_name=value, service_catalog_provisioning_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.project.create project_name=value, service_catalog_provisioning_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_project",
        op_kwargs={
            "ProjectName": project_name,
            "ProjectDescription": project_description,
            "ServiceCatalogProvisioningDetails": service_catalog_provisioning_details,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, project_name: str) -> None:
    r"""
    **Autogenerated function**

    Delete the specified project.

    Args:
        project_name(str): The name of the project to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.project.delete(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.project.delete project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_project",
        op_kwargs={"ProjectName": project_name},
    )


async def describe(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the details of a project.

    Args:
        project_name(str): The name of the project to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.project.describe(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.project.describe project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_project",
        op_kwargs={"ProjectName": project_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the projects in an Amazon Web Services account.

    Args:
        creation_time_after(str, optional): A filter that returns the projects that were created after a specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns the projects that were created before a specified time. Defaults to None.
        max_results(int, optional): The maximum number of projects to return in the response. Defaults to None.
        name_contains(str, optional): A filter that returns the projects whose name contains a specified string. Defaults to None.
        next_token(str, optional): If the result of the previous ListProjects request was truncated, the response includes a NextToken. To retrieve the next set of projects, use the token in the next request. Defaults to None.
        sort_by(str, optional): The field by which to sort results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_projects",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, domain_name: str, deployed: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the access policies that control access to the domain's document and search endpoints. By default, shows the configuration with any pending changes. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Configuring Access for a Search Domain in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.service_access_policy.describe_all(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.service_access_policy.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_service_access_policies",
        op_kwargs={"DomainName": domain_name, "Deployed": deployed},
    )


async def update_multiple(hub, ctx, domain_name: str, access_policies: str) -> Dict:
    r"""
    **Autogenerated function**

    Configures the access rules that control access to the domain's document and search endpoints. For more information, see  Configuring Access for an Amazon CloudSearch Domain.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        access_policies(str): The access rules you want to configure. These rules replace any existing rules. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.service_access_policy.update_multiple(
                ctx, domain_name=value, access_policies=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.service_access_policy.update_multiple domain_name=value, access_policies=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="update_service_access_policies",
        op_kwargs={"DomainName": domain_name, "AccessPolicies": access_policies},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, internet_gateway_id: str, vpc_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Attaches an internet gateway or a virtual private gateway to a VPC, enabling connectivity between the internet and the VPC. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        internet_gateway_id(str): The ID of the internet gateway.
        vpc_id(str): The ID of the VPC.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.internet_gateway.attach(
                ctx, internet_gateway_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.internet_gateway.attach internet_gateway_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="attach_internet_gateway",
        op_kwargs={
            "DryRun": dry_run,
            "InternetGatewayId": internet_gateway_id,
            "VpcId": vpc_id,
        },
    )


async def create(
    hub, ctx, tag_specifications: List = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an internet gateway for use with a VPC. After creating the internet gateway, you attach it to a VPC using AttachInternetGateway. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.

    Args:
        tag_specifications(List, optional): The tags to assign to the internet gateway. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.internet_gateway.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.internet_gateway.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_internet_gateway",
        op_kwargs={"TagSpecifications": tag_specifications, "DryRun": dry_run},
    )


async def delete(hub, ctx, internet_gateway_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified internet gateway. You must detach the internet gateway from the VPC before you can delete it.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        internet_gateway_id(str): The ID of the internet gateway.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.internet_gateway.delete(ctx, internet_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.internet_gateway.delete internet_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_internet_gateway",
        op_kwargs={"DryRun": dry_run, "InternetGatewayId": internet_gateway_id},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    internet_gateway_ids: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your internet gateways.

    Args:
        filters(List, optional): One or more filters.    attachment.state - The current state of the attachment between the gateway and the VPC (available). Present only if a VPC is attached.    attachment.vpc-id - The ID of an attached VPC.    internet-gateway-id - The ID of the Internet gateway.    owner-id - The ID of the Amazon Web Services account that owns the internet gateway.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        internet_gateway_ids(List, optional): One or more internet gateway IDs. Default: Describes all your internet gateways. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.internet_gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.internet_gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_internet_gateways",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "InternetGatewayIds": internet_gateway_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def detach(
    hub, ctx, internet_gateway_id: str, vpc_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Detaches an internet gateway from a VPC, disabling connectivity between the internet and the VPC. The VPC must not contain any running instances with Elastic IP addresses or public IPv4 addresses.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        internet_gateway_id(str): The ID of the internet gateway.
        vpc_id(str): The ID of the VPC.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.internet_gateway.detach(
                ctx, internet_gateway_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.internet_gateway.detach internet_gateway_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="detach_internet_gateway",
        op_kwargs={
            "DryRun": dry_run,
            "InternetGatewayId": internet_gateway_id,
            "VpcId": vpc_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(hub, ctx, resource_id: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from a directory.

    Args:
        resource_id(str): Identifier (ID) of the directory from which to remove the tag.
        tag_keys(List): The tag key (name) of the tag to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.tags.from_resource.remove(
                ctx, resource_id=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.tags.from_resource.remove resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="remove_tags_from_resource",
        op_kwargs={"ResourceId": resource_id, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(hub, ctx, auto_warmup_enabled: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Enable or disable the automatic warm-up feature for dedicated IP addresses.

    Args:
        auto_warmup_enabled(bool, optional): Enables or disables the automatic warm-up feature for dedicated IP addresses that are associated with your Amazon Pinpoint account in the current AWS Region. Set to true to enable the automatic warm-up feature, or set to false to disable it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.account.dedicated_ip_warmup_attribute.put_multiple(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.account.dedicated_ip_warmup_attribute.put_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="put_account_dedicated_ip_warmup_attributes",
        op_kwargs={"AutoWarmupEnabled": auto_warmup_enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    project_name: str,
    placement_name: str,
    device_id: str,
    device_template_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a physical device with a placement.

    Args:
        project_name(str): The name of the project containing the placement in which to associate the device.
        placement_name(str): The name of the placement in which to associate the device.
        device_id(str): The ID of the physical device to be associated with the given placement in the project. Note that a mandatory 4 character prefix is required for all deviceId values.
        device_template_name(str): The device template name to associate with the device ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.device.with_placement.associate(
                ctx,
                project_name=value,
                placement_name=value,
                device_id=value,
                device_template_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.device.with_placement.associate project_name=value, placement_name=value, device_id=value, device_template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="associate_device_with_placement",
        op_kwargs={
            "projectName": project_name,
            "placementName": placement_name,
            "deviceId": device_id,
            "deviceTemplateName": device_template_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, id_: str, status: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables an Amazon Macie administrator to suspend or re-enable a member account.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.
        status(str): Specifies the new status for the account. Valid values are: ENABLED, resume all Amazon Macie activities for the account; and, PAUSED, suspend all Macie activities for the account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.session.update(ctx, id_=value, status=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.session.update id_=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="update_member_session",
        op_kwargs={"id": id_, "status": status},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, resolver_rule_association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an association between a specified Resolver rule and a VPC. You associate a Resolver rule and a VPC using AssociateResolverRule.

    Args:
        resolver_rule_association_id(str): The ID of the Resolver rule association that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.association.get(
                ctx, resolver_rule_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.association.get resolver_rule_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_rule_association",
        op_kwargs={"ResolverRuleAssociationId": resolver_rule_association_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the associations that were created between Resolver rules and VPCs using the current AWS account.

    Args:
        max_results(int, optional): The maximum number of rule associations that you want to return in the response to a ListResolverRuleAssociations request. If you don't specify a value for MaxResults, Resolver returns up to 100 rule associations. . Defaults to None.
        next_token(str, optional): For the first ListResolverRuleAssociation request, omit this value. If you have more than MaxResults rule associations, you can submit another ListResolverRuleAssociation request to get the next group of rule associations. In the next request, specify the value of NextToken from the previous response. . Defaults to None.
        filters(List, optional): An optional specification to return a subset of Resolver rules, such as Resolver rules that are associated with the same VPC ID.  If you submit a second or subsequent ListResolverRuleAssociations request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.association.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.association.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_rule_associations",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, detector_id: str, detector_version_id: str, status: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the detector version’s status. You can perform the following promotions or demotions using UpdateDetectorVersionStatus: DRAFT to ACTIVE, ACTIVE to INACTIVE, and INACTIVE to ACTIVE.

    Args:
        detector_id(str): The detector ID. .
        detector_version_id(str): The detector version ID. .
        status(str): The new status.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.version.status.update(
                ctx, detector_id=value, detector_version_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.version.status.update detector_id=value, detector_version_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_detector_version_status",
        op_kwargs={
            "detectorId": detector_id,
            "detectorVersionId": detector_version_id,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, problem_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an application problem.

    Args:
        problem_id(str): The ID of the problem.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.problem.init.describe(ctx, problem_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.problem.init.describe problem_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_problem",
        op_kwargs={"ProblemId": problem_id},
    )


async def list_all(
    hub,
    ctx,
    resource_group_name: str = None,
    start_time: str = None,
    end_time: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the problems with your application.

    Args:
        resource_group_name(str, optional): The name of the resource group. Defaults to None.
        start_time(str, optional): The time when the problem was detected, in epoch seconds. If you don't specify a time frame for the request, problems within the past seven days are returned. Defaults to None.
        end_time(str, optional): The time when the problem ended, in epoch seconds. If not specified, problems within the past seven days are returned. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.problem.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.problem.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_problems",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "StartTime": start_time,
            "EndTime": end_time,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def count(
    hub,
    ctx,
    domain: str,
    start_time_filter: Dict,
    type_filter: Dict = None,
    tag_filter: Dict = None,
    execution_filter: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    tagFilter.tag: String constraint. The key is swf:tagFilter.tag.    typeFilter.name: String constraint. The key is swf:typeFilter.name.    typeFilter.version: String constraint. The key is swf:typeFilter.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain containing the workflow executions to count.
        start_time_filter(Dict): Specifies the start time criteria that workflow executions must meet in order to be counted.
        type_filter(Dict, optional): Specifies the type of the workflow executions to be counted.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.
        tag_filter(Dict, optional): If specified, only executions that have a tag that matches the filter are counted.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.
        execution_filter(Dict, optional): If specified, only workflow executions matching the WorkflowId in the filter are counted.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.open_workflow_execution.count(
                ctx, domain=value, start_time_filter=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.open_workflow_execution.count domain=value, start_time_filter=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="count_open_workflow_executions",
        op_kwargs={
            "domain": domain,
            "startTimeFilter": start_time_filter,
            "typeFilter": type_filter,
            "tagFilter": tag_filter,
            "executionFilter": execution_filter,
        },
    )


async def list_all(
    hub,
    ctx,
    domain: str,
    start_time_filter: Dict,
    type_filter: Dict = None,
    tag_filter: Dict = None,
    next_page_token: str = None,
    maximum_page_size: int = None,
    reverse_order: bool = None,
    execution_filter: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of open workflow executions in the specified domain that meet the filtering criteria. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    tagFilter.tag: String constraint. The key is swf:tagFilter.tag.    typeFilter.name: String constraint. The key is swf:typeFilter.name.    typeFilter.version: String constraint. The key is swf:typeFilter.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain that contains the workflow executions to list.
        start_time_filter(Dict): Workflow executions are included in the returned results based on whether their start times are within the range specified by this filter.
        type_filter(Dict, optional): If specified, only executions of the type specified in the filter are returned.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.
        tag_filter(Dict, optional): If specified, only executions that have the matching tag are listed.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.
        next_page_token(str, optional): If NextPageToken is returned there are more results available. The value of NextPageToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 60 seconds. Using an expired pagination token will return a 400 error: "Specified token has exceeded its maximum lifetime".  The configured maximumPageSize determines how many results can be returned in a single call. . Defaults to None.
        maximum_page_size(int, optional): The maximum number of results that are returned per call. Use nextPageToken to obtain further pages of results. . Defaults to None.
        reverse_order(bool, optional): When set to true, returns the results in reverse order. By default the results are returned in descending order of the start time of the executions. Defaults to None.
        execution_filter(Dict, optional): If specified, only workflow executions matching the workflow ID specified in the filter are returned.   executionFilter, typeFilter and tagFilter are mutually exclusive. You can specify at most one of these in a request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.open_workflow_execution.list_all(
                ctx, domain=value, start_time_filter=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.open_workflow_execution.list_all domain=value, start_time_filter=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="list_open_workflow_executions",
        op_kwargs={
            "domain": domain,
            "startTimeFilter": start_time_filter,
            "typeFilter": type_filter,
            "tagFilter": tag_filter,
            "nextPageToken": next_page_token,
            "maximumPageSize": maximum_page_size,
            "reverseOrder": reverse_order,
            "executionFilter": execution_filter,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, page_size: str = None, token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the applications that are associated with your Amazon Pinpoint account.

    Args:
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        token(str, optional): The NextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.apps.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.apps.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_apps",
        op_kwargs={"PageSize": page_size, "Token": token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, assessment_target_name: str, resource_group_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target. If the service-linked role isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments. You can create up to 50 assessment targets per AWS account. You can run up to 500 concurrent agents per AWS account. For more information, see  Amazon Inspector Assessment Targets.

    Args:
        assessment_target_name(str): The user-defined name that identifies the assessment target that you want to create. The name must be unique within the AWS account.
        resource_group_arn(str, optional): The ARN that specifies the resource group that is used to create the assessment target. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.target.create(
                ctx, assessment_target_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.target.create assessment_target_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="create_assessment_target",
        op_kwargs={
            "assessmentTargetName": assessment_target_name,
            "resourceGroupArn": resource_group_arn,
        },
    )


async def delete(hub, ctx, assessment_target_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the assessment target that is specified by the ARN of the assessment target.

    Args:
        assessment_target_arn(str): The ARN that specifies the assessment target that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.target.delete(
                ctx, assessment_target_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.target.delete assessment_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="delete_assessment_target",
        op_kwargs={"assessmentTargetArn": assessment_target_arn},
    )


async def describe_all(hub, ctx, assessment_target_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the assessment targets that are specified by the ARNs of the assessment targets.

    Args:
        assessment_target_arns(List): The ARNs that specifies the assessment targets that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.target.describe_all(
                ctx, assessment_target_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.target.describe_all assessment_target_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_assessment_targets",
        op_kwargs={"assessmentTargetArns": assessment_target_arns},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the ARNs of the assessment targets within this AWS account. For more information about assessment targets, see Amazon Inspector Assessment Targets.

    Args:
        filter_(Dict, optional): You can use this parameter to specify a subset of data to be included in the action's response. For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTargets action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.target.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.target.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_assessment_targets",
        op_kwargs={
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    assessment_target_arn: str,
    assessment_target_name: str,
    resource_group_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the assessment target that is specified by the ARN of the assessment target. If resourceGroupArn is not specified, all EC2 instances in the current AWS account and region are included in the assessment target.

    Args:
        assessment_target_arn(str): The ARN of the assessment target that you want to update.
        assessment_target_name(str): The name of the assessment target that you want to update.
        resource_group_arn(str, optional): The ARN of the resource group that is used to specify the new resource group to associate with the assessment target. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.target.update(
                ctx, assessment_target_arn=value, assessment_target_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.target.update assessment_target_arn=value, assessment_target_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="update_assessment_target",
        op_kwargs={
            "assessmentTargetArn": assessment_target_arn,
            "assessmentTargetName": assessment_target_name,
            "resourceGroupArn": resource_group_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables an account as the delegated Amazon Macie administrator account for an Amazon Web Services organization.

    Args:
        admin_account_id(str): The Amazon Web Services account ID of the delegated Amazon Macie administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.organization.admin_account.disable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.organization.admin_account.disable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="disable_organization_admin_account",
        op_kwargs={"adminAccountId": admin_account_id},
    )


async def enable(hub, ctx, admin_account_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Designates an account as the delegated Amazon Macie administrator account for an Amazon Web Services organization.

    Args:
        admin_account_id(str): The Amazon Web Services account ID for the account to designate as the delegated Amazon Macie administrator account for the organization.
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.organization.admin_account.enable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.organization.admin_account.enable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="enable_organization_admin_account",
        op_kwargs={"adminAccountId": admin_account_id, "clientToken": client_token},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the delegated Amazon Macie administrator account for an Amazon Web Services organization.

    Args:
        max_results(int, optional): The maximum number of items to include in each page of a paginated response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.organization.admin_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.organization.admin_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_organization_admin_accounts",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub,
    ctx,
    dry_run: bool = None,
    group_id: str = None,
    group_name: str = None,
    ip_permissions: List = None,
    security_group_rule_descriptions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    [VPC only] Updates the description of an egress (outbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously. You can remove a description for a security group rule by omitting the description parameter in the request.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_id(str, optional): The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID. Defaults to None.
        group_name(str, optional): [Default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. Defaults to None.
        ip_permissions(List, optional): The IP permissions for the security group rule. You must specify either the IP permissions or the description. Defaults to None.
        security_group_rule_descriptions(List, optional): The description for the egress security group rules. You must specify either the description or the IP permissions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.rule.description.egress.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.rule.description.egress.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="update_security_group_rule_descriptions_egress",
        op_kwargs={
            "DryRun": dry_run,
            "GroupId": group_id,
            "GroupName": group_name,
            "IpPermissions": ip_permissions,
            "SecurityGroupRuleDescriptions": security_group_rule_descriptions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "property"


async def get_all(hub, ctx, name: str, run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the workflow run properties which were set during the run.

    Args:
        name(str): Name of the workflow which was run.
        run_id(str): The ID of the workflow run whose run properties should be returned.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.property_.get_all(
                ctx, name=value, run_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.property.get_all name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_workflow_run_properties",
        op_kwargs={"Name": name, "RunId": run_id},
    )


async def put_multiple(hub, ctx, name: str, run_id: str, run_properties: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Puts the specified workflow run properties for the given workflow run. If a property already exists for the specified run, then it overrides the value otherwise adds the property to existing properties.

    Args:
        name(str): Name of the workflow which was run.
        run_id(str): The ID of the workflow run for which the run properties should be updated.
        run_properties(Dict): The properties to put for the specified run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.property_.put_multiple(
                ctx, name=value, run_id=value, run_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.property.put_multiple name=value, run_id=value, run_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="put_workflow_run_properties",
        op_kwargs={"Name": name, "RunId": run_id, "RunProperties": run_properties},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    stack_name: str,
    fleet_name: str,
    user_id: str,
    application_id: str = None,
    validity: int = None,
    session_context: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a temporary URL to start an AppStream 2.0 streaming session for the specified user. A streaming URL enables application streaming to be tested without user setup.

    Args:
        stack_name(str): The name of the stack.
        fleet_name(str): The name of the fleet.
        user_id(str): The identifier of the user.
        application_id(str, optional): The name of the application to launch after the session starts. This is the name that you specified as Name in the Image Assistant. If your fleet is enabled for the Desktop stream view, you can also choose to launch directly to the operating system desktop. To do so, specify Desktop. Defaults to None.
        validity(int, optional): The time that the streaming URL will be valid, in seconds. Specify a value between 1 and 604800 seconds. The default is 60 seconds. Defaults to None.
        session_context(str, optional): The session context. For more information, see Session Context in the Amazon AppStream 2.0 Administration Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.streaming_url.create(
                ctx, stack_name=value, fleet_name=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.streaming_url.create stack_name=value, fleet_name=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_streaming_url",
        op_kwargs={
            "StackName": stack_name,
            "FleetName": fleet_name,
            "UserId": user_id,
            "ApplicationId": application_id,
            "Validity": validity,
            "SessionContext": session_context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an address book with the specified details.

    Args:
        name(str): The name of the address book.
        description(str, optional): The description of the address book. Defaults to None.
        client_request_token(str, optional): A unique, user-specified identifier for the request that ensures idempotency. Defaults to None.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.address_book.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.address_book.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_address_book",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, address_book_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an address book by the address book ARN.

    Args:
        address_book_arn(str): The ARN of the address book to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.address_book.delete(
                ctx, address_book_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.address_book.delete address_book_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_address_book",
        op_kwargs={"AddressBookArn": address_book_arn},
    )


async def get(hub, ctx, address_book_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets address the book details by the address book ARN.

    Args:
        address_book_arn(str): The ARN of the address book for which to request details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.address_book.get(ctx, address_book_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.address_book.get address_book_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_address_book",
        op_kwargs={"AddressBookArn": address_book_arn},
    )


async def search(
    hub,
    ctx,
    filters: List = None,
    sort_criteria: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches address books and lists the ones that meet a set of filter and sort criteria.

    Args:
        filters(List, optional): The filters to use to list a specified set of address books. The supported filter key is AddressBookName. Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of address books. The supported sort key is AddressBookName. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response only includes results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.address_book.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.address_book.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_address_books",
        op_kwargs={
            "Filters": filters,
            "SortCriteria": sort_criteria,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, address_book_arn: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates address book details by the address book ARN.

    Args:
        address_book_arn(str): The ARN of the room to update.
        name(str, optional): The updated name of the room. Defaults to None.
        description(str, optional): The updated description of the room. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.address_book.update(
                ctx, address_book_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.address_book.update address_book_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_address_book",
        op_kwargs={
            "AddressBookArn": address_book_arn,
            "Name": name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str, status_code: str
) -> None:
    r"""
    **Autogenerated function**

    Represents a delete integration response.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a delete integration response request's resource identifier.
        http_method(str): [Required] Specifies a delete integration response request's HTTP method.
        status_code(str): [Required] Specifies a delete integration response request's status code.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.response.delete(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.response.delete rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_integration_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
        },
    )


async def get(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str, status_code: str
) -> Dict:
    r"""
    **Autogenerated function**

    Represents a get integration response.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a get integration response request's resource identifier.
        http_method(str): [Required] Specifies a get integration response request's HTTP method.
        status_code(str): [Required] Specifies a get integration response request's status code.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.response.get(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.response.get rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_integration_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
        },
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    status_code: str,
    selection_pattern: str = None,
    response_parameters: Dict = None,
    response_templates: Dict = None,
    content_handling: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Represents a put integration.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a put integration response request's resource identifier.
        http_method(str): [Required] Specifies a put integration response request's HTTP method.
        status_code(str): [Required] Specifies the status code that is used to map the integration response to an existing MethodResponse.
        selection_pattern(str, optional): Specifies the selection pattern of a put integration response. Defaults to None.
        response_parameters(Dict, optional): A key-value map specifying response parameters that are passed to the method response from the back end. The key is a method response header parameter name and the mapped value is an integration response header value, a static value enclosed within a pair of single quotes, or a JSON expression from the integration response body. The mapping key must match the pattern of method.response.header.{name}, where name is a valid and unique header name. The mapped non-static value must match the pattern of integration.response.header.{name} or integration.response.body.{JSON-expression}, where name must be a valid and unique response header name and JSON-expression a valid JSON expression without the $ prefix. Defaults to None.
        response_templates(Dict, optional): Specifies a put integration response's templates. Defaults to None.
        content_handling(str, optional): Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors:  CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a response payload from a binary blob to a Base64-encoded string.  If this property is not defined, the response payload will be passed through from the integration response to the method response without modification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.response.put(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.response.put rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_integration_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
            "selectionPattern": selection_pattern,
            "responseParameters": response_parameters,
            "responseTemplates": response_templates,
            "contentHandling": content_handling,
        },
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    status_code: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Represents an update integration response.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies an update integration response request's resource identifier.
        http_method(str): [Required] Specifies an update integration response request's HTTP method.
        status_code(str): [Required] Specifies an update integration response request's status code.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.response.update(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.response.update rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_integration_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, authorized_account_id: str, authorized_aws_region: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes the authorization granted to the specified configuration aggregator account in a specified region.

    Args:
        authorized_account_id(str): The 12-digit account ID of the account authorized to aggregate data.
        authorized_aws_region(str): The region authorized to collect aggregated data.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregation_authorization.delete(
                ctx, authorized_account_id=value, authorized_aws_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregation_authorization.delete authorized_account_id=value, authorized_aws_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_aggregation_authorization",
        op_kwargs={
            "AuthorizedAccountId": authorized_account_id,
            "AuthorizedAwsRegion": authorized_aws_region,
        },
    )


async def describe_all(hub, ctx, limit: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of authorizations granted to various aggregator accounts and regions.

    Args:
        limit(int, optional): The maximum number of AggregationAuthorizations returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregation_authorization.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregation_authorization.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_aggregation_authorizations",
        op_kwargs={"Limit": limit, "NextToken": next_token},
    )


async def put(
    hub, ctx, authorized_account_id: str, authorized_aws_region: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Authorizes the aggregator account and region to collect data from the source account and region.

    Args:
        authorized_account_id(str): The 12-digit account ID of the account authorized to aggregate data.
        authorized_aws_region(str): The region authorized to collect aggregated data.
        tags(List, optional): An array of tag object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregation_authorization.put(
                ctx, authorized_account_id=value, authorized_aws_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregation_authorization.put authorized_account_id=value, authorized_aws_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_aggregation_authorization",
        op_kwargs={
            "AuthorizedAccountId": authorized_account_id,
            "AuthorizedAwsRegion": authorized_aws_region,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, portfolio_share_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the status of the specified portfolio share operation. This API can only be called by the management account in the organization or by a delegated admin.

    Args:
        portfolio_share_token(str): The token for the portfolio share operation. This token is returned either by CreatePortfolioShare or by DeletePortfolioShare.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.status.describe(
                ctx, portfolio_share_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.status.describe portfolio_share_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_portfolio_share_status",
        op_kwargs={"PortfolioShareToken": portfolio_share_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    relational_database_name: str,
    duration_in_minutes: int = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of events for a specific database in Amazon Lightsail.

    Args:
        relational_database_name(str): The name of the database from which to get events.
        duration_in_minutes(int, optional): The number of minutes in the past from which to retrieve events. For example, to get all events from the past 2 hours, enter 120. Default: 60  The minimum is 1 and the maximum is 14 days (20160 minutes). Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetRelationalDatabaseEvents request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.event.get_all(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.event.get_all relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_events",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "durationInMinutes": duration_in_minutes,
            "pageToken": page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    session_id: str,
    studio_id: str,
    client_token: str = None,
    expiration_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a streaming session stream for a streaming session. After invoking this API, invoke GetStreamingSessionStream with the returned streamId to poll the resource until it is in state READY.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        expiration_in_seconds(int, optional): The expiration time in seconds. Defaults to None.
        session_id(str): The session ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.stream.create(
                ctx, session_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.stream.create session_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_streaming_session_stream",
        op_kwargs={
            "clientToken": client_token,
            "expirationInSeconds": expiration_in_seconds,
            "sessionId": session_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, session_id: str, stream_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a StreamingSessionStream for a streaming session. Invoke this operation to poll the resource after invoking CreateStreamingSessionStream. After the StreamingSessionStream changes to the state READY, the url property will contain a stream to be used with the DCV streaming client.

    Args:
        session_id(str): The session ID.
        stream_id(str): The stream ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.stream.get(
                ctx, session_id=value, stream_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.stream.get session_id=value, stream_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_streaming_session_stream",
        op_kwargs={
            "sessionId": session_id,
            "streamId": stream_id,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, volume_arn: str, snapshot_description: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a snapshot of a volume. Storage Gateway provides the ability to back up point-in-time snapshots of your data to Amazon Simple Storage (Amazon S3) for durable off-site recovery, and also import the data to an Amazon Elastic Block Store (EBS) volume in Amazon Elastic Compute Cloud (EC2). You can take snapshots of your gateway volume on a scheduled or ad hoc basis. This API enables you to take an ad hoc snapshot. For more information, see Editing a snapshot schedule. In the CreateSnapshot request, you identify the volume by providing its Amazon Resource Name (ARN). You must also provide description for the snapshot. When Storage Gateway takes the snapshot of specified volume, the snapshot and description appears in the Storage Gateway console. In response, Storage Gateway returns you a snapshot ID. You can use this snapshot ID to check the snapshot progress or later use it when you want to create a volume from a snapshot. This operation is only supported in stored and cached volume gateway type.  To list or delete a snapshot, you must use the Amazon EC2 API. For more information, see DescribeSnapshots or DeleteSnapshot in the Amazon Elastic Compute Cloud API Reference.   Volume and snapshot IDs are changing to a longer length ID format. For more information, see the important note on the Welcome page.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.
        snapshot_description(str): Textual description of the snapshot that appears in the Amazon EC2 console, Elastic Block Store snapshots panel in the Description field, and in the Storage Gateway snapshot Details pane, Description field.
        tags(List, optional): A list of up to 50 tags that can be assigned to a snapshot. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.snapshot.init.create(
                ctx, volume_arn=value, snapshot_description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.snapshot.init.create volume_arn=value, snapshot_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_snapshot",
        op_kwargs={
            "VolumeARN": volume_arn,
            "SnapshotDescription": snapshot_description,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def domain(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about the domain, including when the domain was created, the number of items and attributes in the domain, and the size of the attribute names and values.

    Args:
        domain_name(str): The name of the domain for which to display the metadata of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.metadata.domain(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.metadata.domain domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="domain_metadata",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "configuration_for_object_lambda"


async def get(hub, ctx, account_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns configuration for an Object Lambda Access Point. The following actions are related to GetAccessPointConfigurationForObjectLambda:    PutAccessPointConfigurationForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point you want to return the configuration for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.configuration_for_object_lambda_.get(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.configuration_for_object_lambda.get account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_access_point_configuration_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def put(hub, ctx, account_id: str, name: str, configuration: Dict) -> None:
    r"""
    **Autogenerated function**

    Replaces configuration for an Object Lambda Access Point. The following actions are related to PutAccessPointConfigurationForObjectLambda:    GetAccessPointConfigurationForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point.
        configuration(Dict): Object Lambda Access Point configuration document.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.configuration_for_object_lambda_.put(
                ctx, account_id=value, name=value, configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.configuration_for_object_lambda.put account_id=value, name=value, configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_access_point_configuration_for_object_lambda",
        op_kwargs={
            "AccountId": account_id,
            "Name": name,
            "Configuration": configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    states: List = None,
    group_arn: str = None,
    group_name: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the summaries of all insights in the specified group matching the provided filter values.

    Args:
        states(List, optional): The list of insight states. . Defaults to None.
        group_arn(str, optional): The Amazon Resource Name (ARN) of the group. Required if the GroupName isn't provided. Defaults to None.
        group_name(str, optional): The name of the group. Required if the GroupARN isn't provided. Defaults to None.
        start_time(str): The beginning of the time frame in which the insights started. The start time can't be more than 30 days old.
        end_time(str): The end of the time frame in which the insights ended. The end time can't be more than 30 days old.
        max_results(int, optional): The maximum number of results to display. Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.insight.summary.get_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.insight.summary.get_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_insight_summaries",
        op_kwargs={
            "States": states,
            "GroupARN": group_arn,
            "GroupName": group_name,
            "StartTime": start_time,
            "EndTime": end_time,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of tags for the resource identified by a specified Amazon Resource Name (ARN). Tags are used to organize and categorize your CodeDeploy resources.

    Args:
        resource_arn(str):  The ARN of a CodeDeploy resource. ListTagsForResource returns all the tags associated with the resource that is identified by the ResourceArn. .
        next_token(str, optional): An identifier returned from the previous ListTagsForResource call. It can be used to return the next set of applications in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.tags.for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.tags.for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the status of Kinesis streaming.

    Args:
        table_name(str): The name of the table being described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.kinesis_streaming_destination.describe(
                ctx, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.kinesis_streaming_destination.describe table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_kinesis_streaming_destination",
        op_kwargs={"TableName": table_name},
    )


async def disable(hub, ctx, table_name: str, stream_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops replication from the DynamoDB table to the Kinesis data stream. This is done without deleting either of the resources.

    Args:
        table_name(str): The name of the DynamoDB table.
        stream_arn(str): The ARN for a Kinesis data stream.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.kinesis_streaming_destination.disable(
                ctx, table_name=value, stream_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.kinesis_streaming_destination.disable table_name=value, stream_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="disable_kinesis_streaming_destination",
        op_kwargs={"TableName": table_name, "StreamArn": stream_arn},
    )


async def enable(hub, ctx, table_name: str, stream_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts table data replication to the specified Kinesis data stream at a timestamp chosen during the enable workflow. If this operation doesn't return results immediately, use DescribeKinesisStreamingDestination to check if streaming to the Kinesis data stream is ACTIVE.

    Args:
        table_name(str): The name of the DynamoDB table.
        stream_arn(str): The ARN for a Kinesis data stream.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.kinesis_streaming_destination.enable(
                ctx, table_name=value, stream_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.kinesis_streaming_destination.enable table_name=value, stream_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="enable_kinesis_streaming_destination",
        op_kwargs={"TableName": table_name, "StreamArn": stream_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the email sending status of the Amazon SES account for the current region. You can execute this operation no more than once per second.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.account_sending_enabled.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.account_sending_enabled.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ses", operation="get_account_sending_enabled", op_kwargs={}
    )


async def update(hub, ctx, enabled: bool = None) -> None:
    r"""
    **Autogenerated function**

    Enables or disables email sending across your entire Amazon SES account in the current AWS Region. You can use this operation in conjunction with Amazon CloudWatch alarms to temporarily pause email sending across your Amazon SES account in a given AWS Region when reputation metrics (such as your bounce or complaint rates) reach certain thresholds. You can execute this operation no more than once per second.

    Args:
        enabled(bool, optional): Describes whether email sending is enabled or disabled for your Amazon SES account in the current AWS Region. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.account_sending_enabled.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.account_sending_enabled.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="update_account_sending_enabled",
        op_kwargs={"Enabled": enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    function_name: str,
    statement_id: str,
    action: str,
    principal: str,
    source_arn: str = None,
    source_account: str = None,
    event_source_token: str = None,
    qualifier: str = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Grants an Amazon Web Services service or another account permission to use a function. You can apply the policy at the function level, or specify a qualifier to restrict access to a single version or alias. If you use a qualifier, the invoker must use the full Amazon Resource Name (ARN) of that version or alias to invoke the function. To grant permission to another account, specify the account ID as the Principal. For Amazon Web Services services, the principal is a domain-style identifier defined by the service, like s3.amazonaws.com or sns.amazonaws.com. For Amazon Web Services services, you can also specify the ARN of the associated resource as the SourceArn. If you grant permission to a service principal without specifying the source, other accounts could potentially configure resources in their account to invoke your Lambda function. This action adds a statement to a resource-based permissions policy for the function. For more information about function policies, see Lambda Function Policies.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        statement_id(str): A statement identifier that differentiates the statement from others in the same policy.
        action(str): The action that the principal can use on the function. For example, lambda:InvokeFunction or lambda:GetFunction.
        principal(str): The Amazon Web Services service or account that invokes the function. If you specify a service, use SourceArn or SourceAccount to limit who can invoke the function through that service.
        source_arn(str, optional): For Amazon Web Services services, the ARN of the Amazon Web Services resource that invokes the function. For example, an Amazon S3 bucket or Amazon SNS topic. Defaults to None.
        source_account(str, optional): For Amazon S3, the ID of the account that owns the resource. Use this together with SourceArn to ensure that the resource is owned by the specified account. It is possible for an Amazon S3 bucket to be deleted by its owner and recreated by another account. Defaults to None.
        event_source_token(str, optional): For Alexa Smart Home functions, a token that must be supplied by the invoker. Defaults to None.
        qualifier(str, optional): Specify a version or alias to add permissions to a published version of the function. Defaults to None.
        revision_id(str, optional): Only update the policy if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.permission.add(
                ctx, function_name=value, statement_id=value, action=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.permission.add function_name=value, statement_id=value, action=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="add_permission",
        op_kwargs={
            "FunctionName": function_name,
            "StatementId": statement_id,
            "Action": action,
            "Principal": principal,
            "SourceArn": source_arn,
            "SourceAccount": source_account,
            "EventSourceToken": event_source_token,
            "Qualifier": qualifier,
            "RevisionId": revision_id,
        },
    )


async def remove(
    hub,
    ctx,
    function_name: str,
    statement_id: str,
    qualifier: str = None,
    revision_id: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Revokes function-use permission from an Amazon Web Services service or another account. You can get the ID of the statement from the output of GetPolicy.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        statement_id(str): Statement ID of the permission to remove.
        qualifier(str, optional): Specify a version or alias to remove permissions from a published version of the function. Defaults to None.
        revision_id(str, optional): Only update the policy if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.permission.remove(
                ctx, function_name=value, statement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.permission.remove function_name=value, statement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="remove_permission",
        op_kwargs={
            "FunctionName": function_name,
            "StatementId": statement_id,
            "Qualifier": qualifier,
            "RevisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves catalog metadata for a public registry.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.registry.catalog_data.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.registry.catalog_data.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="get_registry_catalog_data",
        op_kwargs={},
    )


async def put(hub, ctx, display_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Create or updates the catalog data for a public registry.

    Args:
        display_name(str, optional): The display name for a public registry. The display name is shown as the repository author in the Amazon ECR Public Gallery.  The registry display name is only publicly visible in the Amazon ECR Public Gallery for verified accounts. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.registry.catalog_data.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.registry.catalog_data.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="put_registry_catalog_data",
        op_kwargs={"displayName": display_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    version: str = None,
    clone_from: str = None,
    binary_media_types: List = None,
    minimum_compression_size: int = None,
    api_key_source: str = None,
    endpoint_configuration: Dict = None,
    policy: str = None,
    tags: Dict = None,
    disable_execute_api_endpoint: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new RestApi resource.

    Args:
        name(str): [Required] The name of the RestApi.
        description(str, optional): The description of the RestApi. Defaults to None.
        version(str, optional): A version identifier for the API. Defaults to None.
        clone_from(str, optional): The ID of the RestApi that you want to clone from. Defaults to None.
        binary_media_types(List, optional): The list of binary media types supported by the RestApi. By default, the RestApi supports only UTF-8-encoded text payloads. Defaults to None.
        minimum_compression_size(int, optional): A nullable integer that is used to enable compression (with non-negative between 0 and 10485760 (10M) bytes, inclusive) or disable compression (with a null value) on an API. When compression is enabled, compression or decompression is not applied on the payload if the payload size is smaller than this value. Setting it to zero allows compression for any payload size. Defaults to None.
        api_key_source(str, optional): The source of the API key for metering requests according to a usage plan. Valid values are: HEADER to read the API key from the X-API-Key header of a request. AUTHORIZER to read the API key from the UsageIdentifierKey from a custom authorizer. Defaults to None.
        endpoint_configuration(Dict, optional): The endpoint configuration of this RestApi showing the endpoint types of the API. Defaults to None.
        policy(str, optional): A stringified JSON policy document that applies to this RestApi regardless of the caller and Method configuration. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.
        disable_execute_api_endpoint(bool, optional): Specifies whether clients can invoke your API by using the default execute-api endpoint. By default, clients can invoke your API with the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To require that clients use a custom domain name to invoke your API, disable the default endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_rest_api",
        op_kwargs={
            "name": name,
            "description": description,
            "version": version,
            "cloneFrom": clone_from,
            "binaryMediaTypes": binary_media_types,
            "minimumCompressionSize": minimum_compression_size,
            "apiKeySource": api_key_source,
            "endpointConfiguration": endpoint_configuration,
            "policy": policy,
            "tags": tags,
            "disableExecuteApiEndpoint": disable_execute_api_endpoint,
        },
    )


async def delete(hub, ctx, rest_api_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified API.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.delete(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.delete rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_rest_api",
        op_kwargs={"restApiId": rest_api_id},
    )


async def get(hub, ctx, rest_api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the RestApi resource in the collection.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.get(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.get rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_rest_api",
        op_kwargs={"restApiId": rest_api_id},
    )


async def import_(
    hub, ctx, body: bytes, fail_on_warnings: bool = None, parameters: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    A feature of the API Gateway control service for creating a new API from an external API definition file.

    Args:
        fail_on_warnings(bool, optional): A query parameter to indicate whether to rollback the API creation (true) or not (false) when a warning is encountered. The default value is false. Defaults to None.
        parameters(Dict, optional): A key-value map of context-specific query string parameters specifying the behavior of different API importing operations. The following shows operation-specific parameters and their supported values.  To exclude DocumentationParts from the import, set parameters as ignore=documentation.  To configure the endpoint type, set parameters as endpointConfigurationTypes=EDGE, endpointConfigurationTypes=REGIONAL, or endpointConfigurationTypes=PRIVATE. The default endpoint type is EDGE.  To handle imported basepath, set parameters as basepath=ignore, basepath=prepend or basepath=split. For example, the AWS CLI command to exclude documentation from the imported API is: aws apigateway import-rest-api --parameters ignore=documentation --body 'file:///path/to/imported-api-body.json' The AWS CLI command to set the regional endpoint on the imported API is: aws apigateway import-rest-api --parameters endpointConfigurationTypes=REGIONAL --body 'file:///path/to/imported-api-body.json'. Defaults to None.
        body(bytes): [Required] The POST request body containing external API definitions. Currently, only OpenAPI definition JSON/YAML files are supported. The maximum size of the API definition file is 6MB.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.import(ctx, body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.import body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="import_rest_api",
        op_kwargs={
            "failOnWarnings": fail_on_warnings,
            "parameters": parameters,
            "body": body,
        },
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    body: bytes,
    mode: str = None,
    fail_on_warnings: bool = None,
    parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A feature of the API Gateway control service for updating an existing API with an input of external API definitions. The update can take the form of merging the supplied definition into the existing API or overwriting the existing API.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        mode(str, optional): The mode query parameter to specify the update mode. Valid values are "merge" and "overwrite". By default, the update mode is "merge". Defaults to None.
        fail_on_warnings(bool, optional): A query parameter to indicate whether to rollback the API update (true) or not (false) when a warning is encountered. The default value is false. Defaults to None.
        parameters(Dict, optional): Custom header parameters as part of the request. For example, to exclude DocumentationParts from an imported API, set ignore=documentation as a parameters value, as in the AWS CLI command of aws apigateway import-rest-api --parameters ignore=documentation --body 'file:///path/to/imported-api-body.json'. Defaults to None.
        body(bytes): [Required] The PUT request body containing external API definitions. Currently, only OpenAPI definition JSON/YAML files are supported. The maximum size of the API definition file is 6MB.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.put(ctx, rest_api_id=value, body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.put rest_api_id=value, body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_rest_api",
        op_kwargs={
            "restApiId": rest_api_id,
            "mode": mode,
            "failOnWarnings": fail_on_warnings,
            "parameters": parameters,
            "body": body,
        },
    )


async def update(hub, ctx, rest_api_id: str, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about the specified API.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_api.update(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_api.update rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_rest_api",
        op_kwargs={"restApiId": rest_api_id, "patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the notification configuration of a bucket. If notifications are not enabled on the bucket, the action returns an empty NotificationConfiguration element. By default, you must be the bucket owner to read the notification configuration of a bucket. However, the bucket owner can use a bucket policy to grant permission to other users to read this configuration with the s3:GetBucketNotification permission. For more information about setting and reading the notification configuration on a bucket, see Setting Up Notification of Bucket Events. For more information about bucket policies, see Using Bucket Policies. The following action is related to GetBucketNotification:    PutBucketNotification

    Args:
        bucket(str): The name of the bucket for which to get the notification configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.notification.configuration.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.notification.configuration.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_notification_configuration",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    notification_configuration: Dict,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Enables notifications of specified events for a bucket. For more information about event notifications, see Configuring Event Notifications. Using this API, you can replace an existing notification configuration. The configuration is an XML file that defines the event types that you want Amazon S3 to publish and the destination where you want Amazon S3 to publish an event notification when it detects an event of the specified type. By default, your bucket has no event notifications configured. That is, the notification configuration will be an empty NotificationConfiguration.  <NotificationConfiguration>   </NotificationConfiguration>  This action replaces the existing notification configuration with the configuration you include in the request body. After Amazon S3 receives this request, it first verifies that any Amazon Simple Notification Service (Amazon SNS) or Amazon Simple Queue Service (Amazon SQS) destination exists, and that the bucket owner has permission to publish to it by sending a test notification. In the case of AWS Lambda destinations, Amazon S3 verifies that the Lambda function permissions grant Amazon S3 permission to invoke the function from the Amazon S3 bucket. For more information, see Configuring Notifications for Amazon S3 Events. You can disable notifications by adding the empty NotificationConfiguration element. By default, only the bucket owner can configure notifications on a bucket. However, bucket owners can use a bucket policy to grant permission to other users to set this configuration with s3:PutBucketNotification permission.  The PUT notification is an atomic operation. For example, suppose your notification configuration includes SNS topic, SQS queue, and Lambda function configurations. When you send a PUT request with this configuration, Amazon S3 sends test messages to your SNS topic. If the message fails, the entire PUT action will fail, and Amazon S3 will not add the configuration to your bucket.   Responses  If the configuration in the request body includes only one TopicConfiguration specifying only the s3:ReducedRedundancyLostObject event type, the response will also include the x-amz-sns-test-message-id header containing the message ID of the test notification sent to the topic. The following action is related to PutBucketNotificationConfiguration:    GetBucketNotificationConfiguration

    Args:
        bucket(str): The name of the bucket.
        notification_configuration(Dict): A container for specifying the notification configuration of the bucket. If this element is empty, notifications are turned off for the bucket.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.notification.configuration.put(
                ctx, bucket=value, notification_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.notification.configuration.put bucket=value, notification_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_notification_configuration",
        op_kwargs={
            "Bucket": bucket,
            "NotificationConfiguration": notification_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, container_name: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a storage container to hold objects. A container is similar to a bucket in the Amazon S3 service.

    Args:
        container_name(str): The name for the container. The name must be from 1 to 255 characters. Container names must be unique to your AWS account within a specific region. As an example, you could create a container named movies in every region, as long as you don’t have an existing container with that name.
        tags(List, optional): An array of key:value pairs that you define. These values can be anything that you want. Typically, the tag key represents a category (such as "environment") and the tag value represents a specific value within that category (such as "test," "development," or "production"). You can add up to 50 tags to each container. For more information about tagging, including naming and usage conventions, see Tagging Resources in MediaStore. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.container.init.create(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.container.init.create container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="create_container",
        op_kwargs={"ContainerName": container_name, "Tags": tags},
    )


async def delete(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified container. Before you make a DeleteContainer request, delete any objects in the container or in any folders in the container. You can delete only empty containers.

    Args:
        container_name(str): The name of the container to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.container.init.delete(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.container.init.delete container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="delete_container",
        op_kwargs={"ContainerName": container_name},
    )


async def describe(hub, ctx, container_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the properties of the requested container. This request is commonly used to retrieve the endpoint of a container. An endpoint is a value assigned by the service when a new container is created. A container's endpoint does not change after it has been assigned. The DescribeContainer request returns a single Container object based on ContainerName. To return all Container objects that are associated with a specified AWS account, use ListContainers.

    Args:
        container_name(str, optional): The name of the container to query. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.container.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.container.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="describe_container",
        op_kwargs={"ContainerName": container_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the properties of all containers in AWS Elemental MediaStore.  You can query to receive all the containers in one response. Or you can include the MaxResults parameter to receive a limited number of containers in each response. In this case, the response includes a token. To get the next set of containers, send the command again, this time with the NextToken parameter (with the returned token as its value). The next set of responses appears, with a token if there are still more containers to receive.  See also DescribeContainer, which gets the properties of one container.

    Args:
        next_token(str, optional): Only if you used MaxResults in the first command, enter the token (which was included in the previous response) to obtain the next set of containers. This token is included in a response only if there actually are more containers to list. Defaults to None.
        max_results(int, optional): Enter the maximum number of containers in the response. Use from 1 to 255 characters. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.container.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.container.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="list_containers",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a specific SpeechSynthesisTask object based on its TaskID. This object contains information about the given speech synthesis task, including the status of the task, and a link to the S3 bucket containing the output of the task.

    Args:
        task_id(str): The Amazon Polly generated identifier for a speech synthesis task.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.speech.synthesis_task.get(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.speech.synthesis_task.get task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="get_speech_synthesis_task",
        op_kwargs={"TaskId": task_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, status: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of SpeechSynthesisTask objects ordered by their creation date. This operation can filter the tasks by their status, for example, allowing users to list only tasks that are completed.

    Args:
        max_results(int, optional): Maximum number of speech synthesis tasks returned in a List operation. Defaults to None.
        next_token(str, optional): The pagination token to use in the next request to continue the listing of speech synthesis tasks. . Defaults to None.
        status(str, optional): Status of the speech synthesis tasks returned in a List operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.speech.synthesis_task.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.speech.synthesis_task.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="list_speech_synthesis_tasks",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Status": status,
        },
    )


async def start(
    hub,
    ctx,
    output_format: str,
    output_s3_bucket_name: str,
    text: str,
    voice_id: str,
    engine: str = None,
    language_code: str = None,
    lexicon_names: List = None,
    output_s3_key_prefix: str = None,
    sample_rate: str = None,
    sns_topic_arn: str = None,
    speech_mark_types: List = None,
    text_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allows the creation of an asynchronous synthesis task, by starting a new SpeechSynthesisTask. This operation requires all the standard information needed for speech synthesis, plus the name of an Amazon S3 bucket for the service to store the output of the synthesis task and two optional parameters (OutputS3KeyPrefix and SnsTopicArn). Once the synthesis task is created, this operation will return a SpeechSynthesisTask object, which will include an identifier of this task as well as the current status.

    Args:
        engine(str, optional): Specifies the engine (standard or neural) for Amazon Polly to use when processing input text for speech synthesis. Using a voice that is not supported for the engine selected will result in an error. Defaults to None.
        language_code(str, optional): Optional language code for the Speech Synthesis request. This is only necessary if using a bilingual voice, such as Aditi, which can be used for either Indian English (en-IN) or Hindi (hi-IN).  If a bilingual voice is used and no language code is specified, Amazon Polly will use the default language of the bilingual voice. The default language for any voice is the one returned by the DescribeVoices operation for the LanguageCode parameter. For example, if no language code is specified, Aditi will use Indian English rather than Hindi. Defaults to None.
        lexicon_names(List, optional): List of one or more pronunciation lexicon names you want the service to apply during synthesis. Lexicons are applied only if the language of the lexicon is the same as the language of the voice. . Defaults to None.
        output_format(str): The format in which the returned output will be encoded. For audio stream, this will be mp3, ogg_vorbis, or pcm. For speech marks, this will be json. .
        output_s3_bucket_name(str): Amazon S3 bucket name to which the output file will be saved.
        output_s3_key_prefix(str, optional): The Amazon S3 key prefix for the output speech file. Defaults to None.
        sample_rate(str, optional): The audio frequency specified in Hz. The valid values for mp3 and ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for standard voices is "22050". The default value for neural voices is "24000". Valid values for pcm are "8000" and "16000" The default value is "16000". . Defaults to None.
        sns_topic_arn(str, optional): ARN for the SNS topic optionally used for providing status notification for a speech synthesis task. Defaults to None.
        speech_mark_types(List, optional): The type of speech marks returned for the input text. Defaults to None.
        text(str): The input text to synthesize. If you specify ssml as the TextType, follow the SSML format for the input text. .
        text_type(str, optional): Specifies whether the input text is plain text or SSML. The default value is plain text. . Defaults to None.
        voice_id(str): Voice ID to use for the synthesis. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.speech.synthesis_task.start(
                ctx, output_format=value, output_s3_bucket_name=value, text=value, voice_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.speech.synthesis_task.start output_format=value, output_s3_bucket_name=value, text=value, voice_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="start_speech_synthesis_task",
        op_kwargs={
            "Engine": engine,
            "LanguageCode": language_code,
            "LexiconNames": lexicon_names,
            "OutputFormat": output_format,
            "OutputS3BucketName": output_s3_bucket_name,
            "OutputS3KeyPrefix": output_s3_key_prefix,
            "SampleRate": sample_rate,
            "SnsTopicArn": sns_topic_arn,
            "SpeechMarkTypes": speech_mark_types,
            "Text": text,
            "TextType": text_type,
            "VoiceId": voice_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(
    hub,
    ctx,
    domain_name: str,
    app_id: str,
    start_time: str = None,
    end_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the website access logs for a specific time range using a presigned URL.

    Args:
        start_time(str, optional):  The time at which the logs should start. The time range specified is inclusive of the start time. . Defaults to None.
        end_time(str, optional):  The time at which the logs should end. The time range specified is inclusive of the end time. . Defaults to None.
        domain_name(str):  The name of the domain. .
        app_id(str):  The unique ID for an Amplify app. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.access_log.generate(
                ctx, domain_name=value, app_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.access_log.generate domain_name=value, app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="generate_access_logs",
        op_kwargs={
            "startTime": start_time,
            "endTime": end_time,
            "domainName": domain_name,
            "appId": app_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, application: str, attribute_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.

    Args:
        application(str): The name or ID of the application.
        attribute_group(str): The name or ID of the attribute group that holds the attributes to describe the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.associate(
                ctx, application=value, attribute_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.associate application=value, attribute_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="associate_attribute_group",
        op_kwargs={"application": application, "attributeGroup": attribute_group},
    )


async def create(
    hub,
    ctx,
    name: str,
    attributes: str,
    client_token: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new attribute group as a container for user-defined attributes. This feature enables users to have full control over their cloud application's metadata in a rich machine-readable format to facilitate integration with automated workflows and third-party tools.

    Args:
        name(str): The name of the attribute group.
        description(str, optional): The description of the attribute group that the user provides. Defaults to None.
        attributes(str): A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components.
        tags(Dict, optional): Key-value pairs you can use to associate with the attribute group. Defaults to None.
        client_token(str): A unique identifier that you provide to ensure idempotency. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.create(
                ctx, name=value, attributes=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.create name=value, attributes=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="create_attribute_group",
        op_kwargs={
            "name": name,
            "description": description,
            "attributes": attributes,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, attribute_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an attribute group, specified either by its attribute group ID or name.

    Args:
        attribute_group(str): The name or ID of the attribute group that holds the attributes to describe the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.delete(
                ctx, attribute_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.delete attribute_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="delete_attribute_group",
        op_kwargs={"attributeGroup": attribute_group},
    )


async def disassociate(hub, ctx, application: str, attribute_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application's metadata. This operation reverts AssociateAttributeGroup.

    Args:
        application(str): The name or ID of the application.
        attribute_group(str): The name or ID of the attribute group that holds the attributes to describe the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.disassociate(
                ctx, application=value, attribute_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.disassociate application=value, attribute_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="disassociate_attribute_group",
        op_kwargs={"application": application, "attributeGroup": attribute_group},
    )


async def get(hub, ctx, attribute_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an attribute group, either by its name or its ID. The attribute group can be specified either by its unique ID or by its name.

    Args:
        attribute_group(str): The name or ID of the attribute group that holds the attributes to describe the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.get(
                ctx, attribute_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.get attribute_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="get_attribute_group",
        op_kwargs={"attributeGroup": attribute_group},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all attribute groups which you have access to. Results are paginated.

    Args:
        next_token(str, optional): The token to use to get the next page of results after a previous API call. . Defaults to None.
        max_results(int, optional): The upper bound of the number of results to return (cannot exceed 25). If this parameter is omitted, it defaults to 25. This value is optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="list_attribute_groups",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    attribute_group: str,
    name: str = None,
    description: str = None,
    attributes: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing attribute group with new details.

    Args:
        attribute_group(str): The name or ID of the attribute group that holds the attributes to describe the application.
        name(str, optional): The new name of the attribute group. The name must be unique in the region in which you are updating the attribute group. Defaults to None.
        description(str, optional): The description of the attribute group that the user provides. Defaults to None.
        attributes(str, optional): A JSON string in the form of nested key-value pairs that represent the attributes in the group and describes an application and its components. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.attribute_group.update(
                ctx, attribute_group=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.attribute_group.update attribute_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="update_attribute_group",
        op_kwargs={
            "attributeGroup": attribute_group,
            "name": name,
            "description": description,
            "attributes": attributes,
        },
    )
